# MadQt
Tutorials and Tools for PyQt and PySide

## Dependencies

Python      >= 3.9

PySide6     >= 6.0.0

Pillow      >= 8.3.0

pyinstaller >= 4.7

# Getting Started

```python
pip install MadQt
```

Visit our [YouTube channel](https://www.youtube.com/c/MadPonyInteractive)

Follow along with our main course on [YouTube](https://youtube.com/playlist?list=PLuvCsqbtUSFAEmez6Tuyi2KitVcS4fLWX)


Support this project:

<a href="https://www.buymeacoffee.com/MadPonyInt" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>
